StanzaRef

Struct StanzaRef 

pub struct StanzaRef<'st>(/* private fields */);
Wrapper for constant reference to Stanza, implements Deref to Stanza

You can obtain such objects by calling Stanza child search methods.

Methods from Deref<Target = Stanza>

pub fn is_text(&self) -> bool

pub fn is_tag(&self) -> bool

pub fn to_text(&self) -> Result<String, ToTextError>

pub fn name(&self) -> Option<&str>

pub fn attribute_count(&self) -> i32

pub fn get_attribute(&self, name: impl AsRef<str>) -> Option<&str>

pub fn attributes(&self) -> HashMap<&str, &str>

xmpp_stanza_get_attributes

This method returns data as HashMap unlike underlying function.

pub fn text(&self) -> Option<String>

pub fn id(&self) -> Option<&str>

pub fn ns(&self) -> Option<&str>

pub fn stanza_type(&self) -> Option<&str>

pub fn to(&self) -> Option<&str>

pub fn from(&self) -> Option<&str>

pub fn get_first_child(&self) -> Option<StanzaRef<'_>>

pub fn get_child_by_ns(&self, ns: impl AsRef<str>) -> Option<StanzaRef<'_>>

pub fn get_child_by_name(&self, name: impl AsRef<str>) -> Option<StanzaRef<'_>>

pub fn get_child_by_name_and_ns( &self, name: impl AsRef<str>, ns: impl AsRef<str>, ) -> Option<StanzaRef<'_>>

pub fn get_child_by_path(&self, path: &[&str]) -> Option<StanzaRef<'_>>

xmpp_stanza_get_child_by_path

Due to internal limitations (vararg call in C) this function supports a maximum of 10 elements in the path slice.

pub fn children(&self) -> impl Iterator<Item = StanzaRef<'_>>

pub fn get_next(&self) -> Option<StanzaRef<'_>>

pub fn reply(&self) -> Self

pub fn reply_error( &self, error_type: impl AsRef<str>, condition: impl AsRef<str>, text: impl AsRef<str>, ) -> Self

pub fn body(&self) -> Option<String>